@@ -29,8 +29,6 @@
 #ifndef _OPENBSD_COMPAT_H
 #define _OPENBSD_COMPAT_H
 
-#include "includes.h"
-
 #include <sys/types.h>
 
 #include <sys/socket.h>
@@ -57,23 +55,23 @@ void closefrom(int);
 
 #if !defined(HAVE_REALPATH) || defined(BROKEN_REALPATH)
 char *realpath(const char *path, char *resolved);
-#endif 
+#endif
 
-#if !HAVE_DECL_STRLCPY
+#if !HAVE_STRLCPY
 size_t strlcpy(char *dst, const char *src, size_t size);
 #endif
 
-#if !HAVE_DECL_STRLCAT
+#if !HAVE_STRLCAT
 size_t strlcat(char *dst, const char *src, size_t size);
 #endif
 
 #ifndef HAVE_STRMODE
-void strmode(int mode, char *p);
+void strmode(mode_t mode, char *p);
 #endif
 
 #ifndef HAVE_DAEMON
 int daemon(int nochdir, int noclose);
-#endif 
+#endif
 
 #ifndef HAVE_DIRNAME
 char *dirname(const char *path);
@@ -88,10 +86,6 @@ int	fmt_scaled(long long number, char *result);
 int	scan_scaled(char *, long long *);
 #endif
 
-#ifndef HAVE_INET_NTOP
-const char *inet_ntop(int af, const void *src, char *dst, socklen_t size);
-#endif
-
 #ifndef HAVE_RES_RANDOMID
 unsigned int res_randomid(void);
 #endif
@@ -100,44 +94,41 @@ unsigned int res_randomid(void);
 char *strsep(char **stringp, const char *delim);
 #endif
 
-#ifdef NEED_SETPROCTITLE
+#ifndef HAVE_SETPROCTITLE
 void setproctitle(const char *fmt, ...);
 void compat_init_setproctitle(int argc, char *argv[]);
 #endif
 
+#ifndef HAVE_GETDTABLECOUNT
+int getdtablecount(void);
+#endif
+
+#ifndef HAVE_GETDTABLESIZE
+int getdtablesize(void);
+#endif
+
 #if !defined(HAVE_GETOPT) || !defined(HAVE_GETOPT_OPTRESET)
 int BSDgetopt(int argc, char * const *argv, const char *opts);
 #endif
 
 /* Home grown routines */
-#include "bsd-misc.h"
 /* #include "bsd-setres_id.h" */
 /* #include "bsd-statvfs.h" */
-#include "bsd-waitpid.h"
+#include "waitpid.h"
 /* #include "bsd-poll.h" */
 
 #ifndef HAVE_GETPEEREID
 int getpeereid(int , uid_t *, gid_t *);
-#endif 
+#endif
 
+/*
+ * XXX some old versions of LibreSSL (pre 3.8) provide 
+ * arc4random(), work around that.
+ */
 #if !defined(HAVE_ARC4RANDOM) || defined(LIBRESSL_VERSION_NUMBER)
 unsigned int arc4random(void);
 #endif
 
-#if 0
-#if defined(LIBRESSL_VERSION_NUMBER)
-# define arc4random_stir()
-#elif defined(HAVE_ARC4RANDOM_STIR)
-void arc4random_stir(void);
-#elif defined(HAVE_ARC4RANDOM)
-/* Recent system/libressl implementation; no need for explicit stir */
-# define arc4random_stir()
-#else
-/* openbsd-compat/arc4random.c provides arc4random_stir() */
-void arc4random_stir(void);
-#endif
-#endif
-
 #if !defined(HAVE_ARC4RANDOM_BUF) || defined(LIBRESSL_VERSION_NUMBER)
 void arc4random_buf(void *, size_t);
 #endif
@@ -146,20 +137,8 @@ void arc4random_buf(void *, size_t);
 uint32_t arc4random_uniform(uint32_t);
 #endif
 
-#if !defined(SSL_OP_NO_CLIENT_RENEGOTIATION) && !defined(LIBRESSL_VERSION_NUMBER)
-#define SSL_OP_NO_CLIENT_RENEGOTIATION 0
-#endif
-
-#ifndef HAVE_ASPRINTF
-int asprintf(char **, const char *, ...);
-#endif 
-
 /* #include <sys/types.h> XXX needed? For size_t */
 
-#ifndef HAVE_SNPRINTF
-int snprintf(char *, size_t, const char *, ...);
-#endif 
-
 #ifndef HAVE_STRTOLL
 long long strtoll(const char *, char **, int);
 #endif
@@ -176,18 +155,6 @@ unsigned long long strtoull(const char *, char **, int);
 long long strtonum(const char *nptr, long long minval, long long maxval, const char **errstr);
 #endif
 
-#if !defined(HAVE_VASPRINTF) || !defined(HAVE_VSNPRINTF)
-# include <stdarg.h>
-#endif
-
-#ifndef HAVE_VASPRINTF
-int vasprintf(char **, const char *, va_list);
-#endif
-
-#ifndef HAVE_VSNPRINTF
-int vsnprintf(char *, size_t, const char *, va_list);
-#endif
-
 #if !defined(HAVE_EXPLICIT_BZERO) || defined(LIBRESSL_VERSION_NUMBER)
 void explicit_bzero(void *p, size_t n);
 #endif
@@ -222,11 +189,6 @@ void *reallocarray(void *, size_t, size_t);
 void *recallocarray(void *, size_t, size_t, size_t);
 #endif
 
-#ifndef HAVE_ERRC
-__attribute__ ((noreturn))
-void errc(int, int, const char *, ...);
-#endif
-
 #if !defined(HAVE_INET_NET_PTON) || defined(HAVE_LIBBSD)
 int inet_net_pton(int, const char *, void *, size_t);
 #endif
@@ -267,10 +229,6 @@ int res_hnok(const char *);
 #define USE_IPV6_ADDR_SCOPE_NODELOCAL 1
 #endif
 
-#ifndef HAVE_FLOCK
-int flock(int, int);
-#endif
-
 #ifndef HAVE_SETRESGID
 int setresgid(uid_t, uid_t, uid_t);
 #endif
@@ -279,10 +237,6 @@ int setresgid(uid_t, uid_t, uid_t);
 int setresuid(uid_t, uid_t, uid_t);
 #endif
 
-#ifndef HAVE_GETLINE
-ssize_t getline(char **, size_t *, FILE *);
-#endif
-
 #ifndef HAVE_CRYPT_CHECKPASS
 int crypt_checkpass(const char *, const char *);
 #endif
@@ -306,7 +260,7 @@ struct timeval {
 int timingsafe_memcmp(const void *, const void *, size_t);
 #endif
 
-#ifdef NEED_NANOSLEEP
+#ifndef HAVE_NANOSLEEP
 #ifndef HAVE_STRUCT_TIMESPEC
 struct timespec {
 	time_t	tv_sec;
@@ -316,29 +270,25 @@ struct timespec {
 int nanosleep(const struct timespec *, struct timespec *);
 #endif
 
-#ifdef NEED_SETEGID
+#ifndef HAVE_SETEGID
 int setegid(uid_t);
 #endif
 
-#ifdef NEED_SETEUID
+#ifndef HAVE_SETEUID
 int seteuid(uid_t);
 #endif
 
-#ifdef NEED_SETSID
+#ifndef HAVE_SETSID
 #define setsid() setpgrp(0, getpid())
 #endif
 
-#ifdef NEED_SIGNAL
+#ifndef HAVE_SIGNAL
 typedef void (*mysig_t)(int);
 mysig_t mysignal(int sig, mysig_t act);
 #define signal(a,b) mysignal(a,b)
 #endif
 
-#ifdef NEED_STRERROR
-const char *strerror(int);
-#endif
-
-#ifdef NEED_USLEEP
+#ifndef HAVE_USLEEP
 int usleep(unsigned int useconds);
 #endif
 
@@ -347,7 +297,7 @@ int pipe2(int pipefd[2], int flags);
 char *get_progname(char *);
 
 
-#ifdef NEED_CLOCK_GETTIME
+#ifndef HAVE_CLOCK_GETTIME
 #ifndef CLOCK_REALTIME
 #define CLOCK_REALTIME	0
 #endif
@@ -357,8 +307,8 @@ char *get_progname(char *);
 int	clock_gettime(int clock_id, struct timespec *tp);
 #endif
 
-#ifdef NEED_GETSUBOPT
-#define getsubopt(optionp, tockens, valuep) openbsd_getsubopt(optionp, tockens, valuep)
+#ifndef HAVE_SUBOPTARG
+#define getsubopt(optionp, tokens, valuep) openbsd_getsubopt(optionp, tokens, valuep)
 int openbsd_getsubopt(char **optionp, char * const *tokens, char **valuep);
 extern  char *suboptarg;               /* getsubopt(3) external variable */
 #endif
