@@ -1,4 +1,4 @@
-/*	$OpenBSD: bounce.c,v 1.89 2023/05/15 12:03:04 op Exp $	*/
+/*	$OpenBSD: bounce.c,v 1.90 2023/05/31 16:51:46 op Exp $	*/
 
 /*
  * Copyright (c) 2009 Gilles Chehade <gilles@poolp.org>
@@ -546,8 +546,8 @@ bounce_next(struct bounce_session *s)
 			if ((len = getline(&line, &sz, s->msgfp)) == -1)
 				break;
 			if (len == 1 && line[0] == '\n' && /* end of headers */
-			    s->msg->bounce.type == B_DELIVERED &&
-			    s->msg->bounce.dsn_ret ==  DSN_RETHDRS) {
+			    (s->msg->bounce.type != B_FAILED ||
+			    s->msg->bounce.dsn_ret != DSN_RETFULL)) {
 				free(line);
 				fclose(s->msgfp);
 				s->msgfp = NULL;
