@@ -1,4 +1,4 @@
-/*	$OpenBSD: mproc.c,v 1.47 2024/11/21 13:42:22 claudio Exp $	*/
+/*	$OpenBSD: mproc.c,v 1.48 2025/10/30 16:46:19 gilles Exp $	*/
 
 /*
  * Copyright (c) 2012 Eric Faurot <eric@faurot.net>
@@ -154,6 +154,14 @@ mproc_dispatch(int fd, short event, void *arg)
 
 		switch (n) {
 		case -1:
+			if (smtpd_process == PROC_CONTROL &&
+			    p->proc == PROC_CLIENT) {
+				log_warnx("warn: client sent invalid imsg "
+				    "over control socket");
+				p->handler(p, NULL);
+				return;
+			}
+
 			log_warn("warn: %s -> %s: imsgbuf_read",
 			    proc_name(smtpd_process),  p->name);
 			fatal("exiting");
