@@ -1,4 +1,4 @@
-/*	$OpenBSD: scheduler_proc.c,v 1.10 2024/05/07 12:10:06 op Exp $	*/
+/*	$OpenBSD: scheduler_proc.c,v 1.13 2024/11/21 13:42:22 claudio Exp $	*/
 
 /*
  * Copyright (c) 2013 Eric Faurot <eric@openbsd.org>
@@ -40,8 +40,8 @@ scheduler_proc_call(void)
 {
 	ssize_t	n;
 
-	if (imsg_flush(&ibuf) == -1) {
-		log_warn("warn: scheduler-proc: imsg_flush");
+	if (imsgbuf_flush(&ibuf) == -1) {
+		log_warn("warn: scheduler-proc: imsgbuf_flush");
 		fatalx("scheduler-proc: exiting");
 	}
 
@@ -61,8 +61,8 @@ scheduler_proc_call(void)
 			return;
 		}
 
-		if ((n = imsg_read(&ibuf)) == -1 && errno != EAGAIN) {
-			log_warn("warn: scheduler-proc: imsg_read");
+		if ((n = imsgbuf_read(&ibuf)) == -1) {
+			log_warn("warn: scheduler-proc: imsgbuf_read");
 			break;
 		}
 
@@ -112,7 +112,9 @@ scheduler_proc_init(const char *conf)
 	if (fd == -1)
 		fatalx("scheduler-proc: exiting");
 
-	imsg_init(&ibuf, fd);
+	if (imsgbuf_init(&ibuf, fd) == -1)
+		fatal("scheduler-proc: exiting");
+	imsgbuf_allow_fdpass(&ibuf);
 
 	version = PROC_SCHEDULER_API_VERSION;
 	imsg_compose(&ibuf, PROC_SCHEDULER_INIT, 0, 0, -1,
