@@ -1,4 +1,4 @@
-/*	$OpenBSD: ssl.c,v 1.98 2022/02/18 16:57:36 millert Exp $	*/
+/*	$OpenBSD: ssl.c,v 1.100 2023/06/25 08:08:03 op Exp $	*/
 
 /*
  * Copyright (c) 2008 Pierre-Yves Ritschard <pyr@openbsd.org>
@@ -28,7 +28,6 @@
 
 #include <fcntl.h>
 #include <limits.h>
-#include <openssl/engine.h>
 #include <openssl/err.h>
 #include <openssl/ssl.h>
 #include <string.h>
@@ -37,25 +36,6 @@
 #include "log.h"
 #include "ssl.h"
 
-void
-ssl_init(void)
-{
-	static int	inited = 0;
-
-	if (inited)
-		return;
-
-	SSL_library_init();
-	SSL_load_error_strings();
-
-	OpenSSL_add_all_algorithms();
-
-	/* Init hardware crypto engines. */
-	ENGINE_load_builtin_engines();
-	ENGINE_register_all_complete();
-	inited = 1;
-}
-
 static char *
 ssl_load_file(const char *name, off_t *len, mode_t perm)
 {
@@ -146,9 +126,6 @@ ssl_load_key(const char *name, off_t *len, char *pass, mode_t perm, const char *
 	char		 mode[12];
 	char		 prompt[2048];
 
-	/* Initialize SSL library once */
-	ssl_init();
-
 	/*
 	 * Read (possibly) encrypted key from file
 	 */
@@ -263,7 +240,7 @@ hash_x509(X509 *cert, char *hash, size_t hashlen)
 		fatalx("%s: X509_pubkey_digest failed", __func__);
 
 	if (hashlen < 2 * dlen + sizeof("SHA256:"))
-		fatalx("%s: hash buffer to small", __func__);
+		fatalx("%s: hash buffer too small", __func__);
 
 	off = strlcpy(hash, "SHA256:", hashlen);
 
